@@ -19,10 +19,12 @@ from typing import (
     Tuple,
 )
 
+import click
+
 import git
 
 from tartufo import config, types, util
-from tartufo.types import Rule, TartufoException
+from tartufo.types import BranchNotFoundException, Rule, TartufoException
 
 BASE64_CHARS = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/="
 HEX_CHARS = "1234567890abcdefABCDEF"
@@ -31,12 +33,20 @@ HEX_CHARS = "1234567890abcdefABCDEF"
 class Issue:
     """Represent an issue found while scanning a target."""
 
-    OUTPUT_SEPARATOR: str = "~~~~~~~~~~~~~~~~~~~~~"
+    __slots__ = (
+        "OUTPUT_SEPARATOR",
+        "chunk",
+        "issue_type",
+        "issue_detail",
+        "matched_string",
+        "logger",
+    )
 
+    OUTPUT_SEPARATOR: str
     chunk: types.Chunk
     issue_type: types.IssueType
-    issue_detail: Optional[str] = None
-    matched_string: str = ""
+    issue_detail: Optional[str]
+    matched_string: str
     logger: logging.Logger
 
     def __init__(
@@ -47,6 +57,9 @@ class Issue:
         :param matched_string: The string that was identified as a potential issue
         :param chunk: The chunk of data where the match was found
         """
+        self.OUTPUT_SEPARATOR = "~~~~~~~~~~~~~~~~~~~~~"  # pylint: disable=invalid-name
+        self.issue_detail = None
+
         self.issue_type = issue_type
         self.matched_string = matched_string
         self.chunk = chunk
@@ -243,7 +256,7 @@ class ScannerBase(abc.ABC):
         this function when no inclusions or exclusions exist.
 
         :param file_path: The file path to check for inclusion
-        :return: False if the file path is _not_ matched by `self.indluded_paths`
+        :return: False if the file path is _not_ matched by `self.included_paths`
             (when non-empty) or if it is matched by `self.excluded_paths` (when
             non-empty), otherwise returns True
         """
@@ -465,11 +478,11 @@ class GitScanner(ScannerBase, abc.ABC):
         diff: git.Diff
         for diff in diff_index:
             file_path = diff.b_path if diff.b_path else diff.a_path
-            printable_diff: str = diff.diff.decode("utf-8", errors="replace")
-            if printable_diff.startswith("Binary files"):
-                self.logger.debug("Binary file skipped: %s", file_path)
-                continue
             if self.should_scan(file_path):
+                printable_diff = diff.diff.decode("utf-8", errors="replace")
+                if printable_diff.startswith("Binary files"):
+                    self.logger.debug("Binary file skipped: %s", file_path)
+                    continue
                 yield (printable_diff, file_path)
 
     def filter_submodules(self, repo: git.Repo) -> None:
@@ -522,7 +535,7 @@ class GitRepoScanner(GitScanner):
             (config_file, data) = config.load_config_from_path(
                 pathlib.Path(repo_path), traverse=False
             )
-        except (FileNotFoundError, types.ConfigException) as exc:
+        except (FileNotFoundError, types.ConfigException):
             config_file = None
         if config_file and config_file != self.global_options.config:
             signatures = data.get("exclude_signatures", None)
@@ -607,6 +620,11 @@ class GitRepoScanner(GitScanner):
                 branches = [
                     x for x in unfiltered_branches if x.name == self.git_options.branch
                 ]
+
+                if len(branches) == 0:
+                    raise BranchNotFoundException(
+                        f"Branch {self.git_options.branch} was not found."
+                    )
             else:
                 # Everything
                 if self.git_options.fetch:
@@ -683,3 +701,51 @@ class GitPreCommitScanner(GitScanner):
         )
         for blob, file_path in self._iter_diff_index(diff_index):
             yield types.Chunk(blob, file_path, {})
+
+
+class FolderScanner(ScannerBase):
+    """Used to scan a folder."""
+
+    target: str
+
+    def __init__(
+        self,
+        global_options: types.GlobalOptions,
+        target: str,
+    ) -> None:
+        """Used for scanning a folder.
+
+        :param global_options: The options provided to the top-level tartufo command
+        :param target: The local filesystem path to scan
+        """
+        self.target = target
+        super().__init__(global_options)
+
+    @property
+    def chunks(self) -> Generator[types.Chunk, None, None]:
+        """Yield the individual files in the target directory.
+
+        :rtype: Generator[Chunk, None, None]
+        """
+
+        for blob, file_path in self._iter_folder():
+            yield types.Chunk(blob, file_path, {})
+
+    def _iter_folder(self) -> Generator[Tuple[str, str], None, None]:
+        folder_path = pathlib.Path(self.target)
+        for file_path in folder_path.rglob("**/*"):
+            relative_path = file_path.relative_to(folder_path)
+            if file_path.is_file() and self.should_scan(str(relative_path)):
+                try:
+                    with file_path.open("rb") as fhd:
+                        data = fhd.read()
+                except OSError as exc:
+                    raise click.FileError(filename=str(file_path), hint=str(exc))
+
+                try:
+                    blob = data.decode("utf-8")
+                except UnicodeDecodeError:
+                    # binary file, continue
+                    continue
+
+                yield blob, str(relative_path)
